<?php

namespace App\Http\Controllers\Api\Auth;

use App\Exceptions\InvalidOtpException;
use App\Http\Controllers\Controller;
use App\Http\Requests\VerifyOtpRequest;
use App\Models\Otp;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Log;

class MobileNumberVerificationController extends Controller
{
    public function sendOtp(Request $request)
    {
        if($request->user()->hasVerifiedMobileNumber())
        {
            return $this->successResponse('You have already verified your phone number');
        }

        $request->user()->sendMobileNumberVerificationNotification();
        return $this->successResponse('Your OTP Has been seen to your phone number', ['mobile_number' => Auth::user()->mobile_number], 201);
    }

    public function verifyOtp(VerifyOtpRequest $request)
    {
        if ($request->user()->hasVerifiedMobileNumber())
        {
            return $this->successResponse('You have already verified your mobile number');
        }

        $otp = $request->user()->otps()
                    ->orderBy('created_at', 'desc')
                    ->first();
        if (!$this->validateOtp($otp) ||  !Hash::check($request->validated('code'), $otp->code))
        {
            throw new InvalidOtpException('The code you have entered is invalid or has expired');
        }

        try {
            DB::transaction(function () use($request, $otp) {
                $otp->update([
                    'is_used' => true
                ]);

                $request->user()->markMobileNumberAsVerified();

            });

            return $this->successResponse(message: 'You have successfully verified you phone number');
        } catch (\Throwable $th) {
            Log::error($th->getMessage(), ['Verify Otp']);
            return $this->errorResponse('Unable to verify your mobile number. Please try again', statusCode: 500);
        }

    }

    protected function validateOtp(Otp $otp)
    {
        if(!$otp || $otp->expires_at < now() || $otp->is_used)
        {
            return false;
        }
        return true;

    }
}
