<?php

namespace App\Http\Requests\Auth;

use App\Enums\Gender;
use App\Enums\UserType;
use App\Models\User;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rule;
use Illuminate\Validation\Rules;
use Illuminate\Validation\Rules\File;

class RegisterRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     */
    public function authorize(): bool
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, \Illuminate\Contracts\Validation\ValidationRule|array<mixed>|string>
     */
    public function rules(): array
    {
        return [
            'user_type' => ['required', Rule::enum(UserType::class)],
            'name' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'lowercase', 'email', 'max:255', 'unique:'.User::class],
            'password' => ['required', 'confirmed', Rules\Password::defaults()],
            'mobile_number' => ['required', 'string', 'max:15'],
            'gender' => ['nullable', 'string'],
            'date_of_birth' => ['nullable', 'date'],
            'occupation' => ['nullable', 'string'],
            'hobbies' => ['nullable', 'string'],
            'additional_number' => ['nullable', 'string', 'max:15'],
            'referral_code' => ['nullable', 'exists:referrals,code'],
            'device_name' => ['nullable', 'string'],
            'profile_picture' => [
                'nullable',
                File::image()
                    ->max('1mb')
            ]
        ];
    }

    public static function fake()
    {
        return [
            'user_type' => fake()->randomElement(UserType::cases())->value,
            'name' => fake()->name(),
            'email' => fake()->unique()->email(),
            'password' => 'password',
            'password_confirmation' => 'password',
            'mobile_number' => substr(fake()->phoneNumber(), 0, 15),
            'gender' => fake()->randomElement(Gender::cases())->value,

            'date_of_birth' => fake()->dateTimeBetween(endDate: '-18 years')->format('Y-m-d 00:00:00'),
            'occupation' => fake()->jobTitle(),
            'hobbies' => implode(', ',fake()->words()),
            'additional_number' => substr(fake()->phoneNumber(), 0, 15),
            'device_name' => 'mobile',
        ];
    }

}
