<?php

namespace App\Models\Traits;

use App\Models\Otp;
use App\Notifications\VerifyMobileNumber;
use Illuminate\Support\Facades\Hash;

trait MustVerifyMobileNumber
{
    /**
     * Determine if the user has verified their mobile number.
     *
     * @return bool
     */
    public function hasVerifiedMobileNumber()
    {
        return ! is_null($this->mobile_number_verified_at);
    }

    /**
     * Mark the given user's email as verified.
     *
     * @return bool
     */
    public function markMobileNumberAsVerified()
    {
        return $this->forceFill([
            'mobile_number_verified_at' => $this->freshTimestamp(),
        ])->save();
    }

    /**
     * Send the email verification notification.
     *
     * @return void
     */
    public function sendMobileNumberVerificationNotification()
    {
        $otp = Otp::generateCode();
        $this->otps()->create([
            'code' => Hash::make($otp),
            'expires_at' => now()->addMinutes(Otp::EXPIRATION_TIME),
        ]);
        $this->notify(new VerifyMobileNumber($otp));
    }

    /**
     * Get the mobile number that should be used for verification.
     *
     * @return string
     */
    public function getMobileNumberForVerification()
    {
        return $this->mobile_number;
    }

    public function otps()
    {
        return $this->hasMany(Otp::class, 'user_id');
    }
}
