<?php

namespace App\Services;

use App\DataTransferObjects\RegisterUserDto;
use App\Models\Referral;
use App\Models\User;
use Illuminate\Auth\Events\Registered;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;

class RegistrationService{

    /**
     * Create a new user based on it's user type, attach the
     * appropriate role to it, dispatch an event, then create a token
     * return an array of the the token and the user type
     * @param \App\DataTransferObjects\RegisterUserDto $registerUserDto
     * @return User
     */
    public function registerUser(RegisterUserDto $registerUserDto): User
    {
        return DB::transaction(function () use ($registerUserDto) {
            /**
             * @var User
             */
            $user = User::create([
                'name' => $registerUserDto->name,
                'email' => $registerUserDto->email,
                'password' => Hash::make($registerUserDto->password),
                'gender' => $registerUserDto->gender,
                'occupation' => $registerUserDto->occupation,
                'hobbies' => $registerUserDto->hobbies,
                'date_of_birth' => $registerUserDto->dateOfBirth,
                'additional_number' => $registerUserDto->additionalNumber,
                'mobile_number' => $registerUserDto->mobileNumber,
                'referral_id' => $registerUserDto->referralCode
                                        ? Referral::where('code', $registerUserDto->referralCode)->first()->id
                                        : null,
            ]);

            $user->assignRole($registerUserDto->userType->value);

            event(new Registered($user));

            return $user;
        });
    }
}
