<?php

namespace Database\Factories;

use App\Enums\UserType;
use App\Models\User;
use Illuminate\Database\Eloquent\Factories\Factory;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;

/**
 * @extends \Illuminate\Database\Eloquent\Factories\Factory<\App\Models\User>
 */
class UserFactory extends Factory
{
    /**
     * The current password being used by the factory.
     */
    protected static ?string $password;

    /**
     * Define the model's default state.
     *
     * @return array<string, mixed>
     */
    public function definition(): array
    {
        return [
            'name' => fake()->name(),
            'email' => fake()->unique()->safeEmail(),
            'mobile_number' => fake()->phoneNumber(),
            'email_verified_at' => now(),
            'mobile_number_verified_at' => now(),
            'password' => static::$password ??= Hash::make('password'),
            'remember_token' => Str::random(10),
        ];
    }

    /**
     * Indicate that the model's email address should be unverified.
     */
    public function unverified(): static
    {
        return $this->state(fn (array $attributes) => [
            'email_verified_at' => null,
        ]);
    }

    /**
     * Indicate that the model's mobile number should be unverified.
     */
    public function unverifiedNumber(): static
    {
        return $this->state(fn (array $attributes) => [
            'mobile_number_verified_at' => null,
        ]);
    }

    public function assignRole(UserType $userType)
    {
        return $this->afterMaking(function (User $user) use ($userType) {
            $user->syncRoles($userType->value);
        });
    }

    // public function configure()
    // {
    //     return $this->afterMaking(function (User $user) {
    //         $user->syncRoles(fake()->randomElement(UserType::cases()));
    //     });
    // }

}
