<?php

use App\Enums\UserType;
use App\Models\User;
use Illuminate\Testing\Fluent\AssertableJson;
use Illuminate\Testing\TestResponse;

use function Pest\Laravel\assertDatabaseCount;
use function Pest\Laravel\post;


test('users can authenticate', function () {
    $user = User::factory()->assignRole(UserType::User)->create();

    /**
     * @var TestResponse
     */
    $response = $this->post('/api/login', [
        'email' => $user->email,
        'password' => 'password',
    ]);

    $this->assertDatabaseCount('personal_access_tokens', 1);
    $response
        ->assertStatus(200)
        ->assertJson(function (AssertableJson $json) {
            $json->has('data.token')
                ->has('data.user_type')
                ->etc();
        })
        ->assertJsonPath('data.user_type', UserType::User->value);

});

test('users can not authenticate with invalid password', function () {
    $user = User::factory()->create();

    $response = $this->post('/api/login', [
        'email' => $user->email,
        'password' => 'wrong-password',
    ], ['Accept' => 'application/json']);

    $response
        ->assertInvalid('email');


});

test('users can logout', function () {
    $user = User::factory()->create();

    // Generate a token for the user
    $token = $user->createToken('Test Token')->plainTextToken;

    // Send a POST request to the logout endpoint with the token in the headers
    /**
     * @var TestResponse
     */
    $response = post('/api/logout', headers:[
        'Authorization' => 'Bearer ' . $token,
        'Accept' => 'application/json'
    ]);


    $response->assertJsonStructure(['message']);
    assertDatabaseCount('personal_access_tokens', 0);

});
