<?php

use App\Enums\UserType;
use App\Http\Requests\Auth\RegisterRequest;
use App\Models\Otp;
use App\Models\User;
use App\Notifications\VerifyMobileNumber;
use Illuminate\Auth\Events\Registered;
use Illuminate\Support\Facades\Event;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Notification;
use Illuminate\Testing\TestResponse;

use function Pest\Laravel\assertDatabaseHas;
use function Pest\Laravel\post;
use function PHPUnit\Framework\assertNotNull;
use function PHPUnit\Framework\assertTrue;



test('new users can register', function () {
    $payload = RegisterRequest::fake();
    Event::fake();

    $response = post('/api/register', $payload);

    Event::assertDispatched(Registered::class);
    $response->assertStatus(201);
    $this->assertDatabaseCount('users', 1);

    $keysToRemove = ['password', 'password_confirmation', 'user_type', 'device_name', 'profile_picture'];
    $this->assertDatabaseHas('users', array_diff_key($payload, array_flip($keysToRemove)));
});

test('normal user has the appropriate user type assigned to them', function () {
    $payload = [
        'name' => 'Test User',
        'email' => 'test@example.com',
        'password' => 'password',
        'password_confirmation' => 'password',
        'user_type' => UserType::User->value,
        'mobile_number' => "09029276583",
        'device_name' => 'test device',
    ];

    /**
     * @var TestResponse
     */
    $response = $this->post('/api/register', $payload);
    expect(
        User::where('email', $payload['email'])
                    ->first()
                    ->getRoleName()
        )
        ->toBe(
            UserType::User->value,
            'The role name of the user is not the same as the user type that was submitted'
        );

});


test('the referrer gets a allocated with the right amount of points when he refers another user', function () {

});

test('otp is sent to the phone number when they register', function (){
    Notification::fake();
    $payload = RegisterRequest::fake();
    $response = post('/api/register', $payload);
    $response->assertStatus(201);

    $user = User::where('email', $payload['email'])->first();
    Notification::assertSentTo(
        $user,
        VerifyMobileNumber::class,
        function(VerifyMobileNumber $verifyMobileNumber, $channels) use ($user) {
            assertNotNull($verifyMobileNumber->otp);
            assertDatabaseHas('otps', [
                'user_id' => $user->id,
                'is_used' => false,
            ]);
            assertTrue(Hash::check($verifyMobileNumber->otp, Otp::first()->code));
            return true;
        }
    );
});
